'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var backendCommon = require('@backstage/backend-common');
var catalogModel = require('@backstage/catalog-model');

class BatchLoader {
  constructor(options) {
    this.logger = options.logger;
    this.manager = options.databaseManager;
    this.client = this.manager.forPlugin("catalog").getClient();
  }
  async init() {
    this.logger.info("Initializing batch loader");
    const client = await this.client;
    const migrationsDir = backendCommon.resolvePackagePath("@frontside/backstage-plugin-batch-loader", "migrations");
    this.logger.info(`Running migrations from ${migrationsDir}`);
    await client.raw("CREATE SCHEMA IF NOT EXISTS refs;");
    await client.migrate.latest({
      schemaName: "refs",
      directory: migrationsDir
    });
  }
  async getEntitiesByRefs(refs) {
    this.logger.info(`Loading entities for refs: ${refs}`);
    const client = await this.client;
    const stringifiedRefs = refs.map((ref) => typeof ref === "string" ? ref : catalogModel.stringifyEntityRef(ref));
    const rows = await client("refs.entities").select("*").whereIn("refs.entities.ref", stringifiedRefs);
    const unsortedEntities = new Map(rows.map((row) => [row.ref, JSON.parse(row.final_entity)]));
    const entities = stringifiedRefs.map((ref) => unsortedEntities.get(ref));
    this.logger.info(`Loaded ${entities.length} entities`);
    return entities;
  }
}

exports.BatchLoader = BatchLoader;
//# sourceMappingURL=index.cjs.js.map
